@@ -98,7 +98,10 @@ glade_xml_init (GladeXML *self)
 
 	self->filename = NULL;
 	self->txtdomain = NULL;
-	priv->tooltips = NULL;
+
+	priv->tree = NULL;
+	priv->tooltips = gtk_tooltips_new();
+	gtk_tooltips_enable(priv->tooltips);
 	priv->name_hash = g_hash_table_new(g_str_hash, g_str_equal);
 	priv->longname_hash = g_hash_table_new(g_str_hash, g_str_equal);
 	priv->signals = g_hash_table_new(g_str_hash, g_str_equal);
@@ -202,9 +205,6 @@ glade_xml_construct (GladeXML *self, const char *fname, const char *root,
 	self->filename = g_strdup(fname);
 	glade_xml_build_interface(self, tree, root);
 
-	if (self->priv->tooltips)
-		gtk_tooltips_enable(self->priv->tooltips);
-
 	return TRUE;
 }
 
@@ -238,9 +238,6 @@ GladeXML *glade_xml_new_from_memory(char *buffer, int size, const char *root,
 	self->filename = NULL;
 	glade_xml_build_interface(self, tree, root);
 
-	if (self->priv->tooltips)
-		gtk_tooltips_enable(self->priv->tooltips);
-
 	return self;
 }
 
@@ -700,6 +697,8 @@ glade_get_widget_tree(GtkWidget *widget)
 void
 glade_xml_set_toplevel(GladeXML *xml, GtkWindow *window)
 {
+	static char *tooltips_key = "libglade::GladeXML::tooltips";
+
 	if (xml->priv->focus_widget)
 		gtk_widget_grab_focus(xml->priv->focus_widget);
 	if (xml->priv->default_widget)
@@ -708,9 +707,16 @@ glade_xml_set_toplevel(GladeXML *xml, GtkWindow *window)
 	xml->priv->default_widget = NULL;
 	xml->priv->toplevel = window;
 	/* new toplevel needs new accel group */
-	g_slist_free(xml->priv->accel_groups);
+	if (xml->priv->accel_groups)
+		glade_xml_pop_accel(xml);
+	/* maybe put an assert that xml->priv->accel_groups == NULL here? */
 	xml->priv->accel_groups = NULL;
 	xml->priv->parent_accel = 0;
+	/* the window should hold a reference to the tooltips object */
+	gtk_object_ref(GTK_OBJECT(xml->priv->tooltips));
+	gtk_object_set_data_full(GTK_OBJECT(window), tooltips_key,
+				 xml->priv->tooltips,
+				 (GtkDestroyNotify)gtk_object_unref);
 }
 
  /**
@@ -722,7 +728,8 @@ glade_xml_set_toplevel(GladeXML *xml, GtkWindow *window)
  * Returns: The current GtkAccelGroup after push.
  */
 GtkAccelGroup *
-glade_xml_push_accel(GladeXML *xml) {
+glade_xml_push_accel(GladeXML *xml)
+{
 	GtkAccelGroup *accel = gtk_accel_group_new();
        
 	xml->priv->accel_groups
@@ -738,12 +745,18 @@ glade_xml_push_accel(GladeXML *xml) {
  * Returns: The current GtkAccelGroup after pop.
  */
 GtkAccelGroup *
-glade_xml_pop_accel(GladeXML *xml) {
+glade_xml_pop_accel(GladeXML *xml)
+{
+	GtkAccelGroup *accel;
+
 	g_return_val_if_fail(xml->priv->accel_groups != NULL, NULL);
 
+	/* the accel group at the top of the stack */
+	accel = xml->priv->accel_groups->data;
 	xml->priv->accel_groups
-		= g_slist_remove(xml->priv->accel_groups,
-				 xml->priv->accel_groups->data);
+		= g_slist_remove(xml->priv->accel_groups, accel);
+	/* unref the accel group that was at the top of the stack */
+	gtk_accel_group_unref(accel);
 	return xml->priv->accel_groups ? xml->priv->accel_groups->data : NULL;
 }
 
@@ -971,25 +984,38 @@ glade_xml_destroy(GtkObject *object)
 	
 	if (self->filename)
 		g_free(self->filename);
+	self->filename = NULL;
 	if (self->txtdomain)
 		g_free(self->txtdomain);
+	self->txtdomain = NULL;
 
-	if (priv->tree)
-		glade_widget_tree_unref(priv->tree);
-	/* strings are owned in the cached GladeWidgetTree structure */
-	g_hash_table_destroy(priv->name_hash);
-	/* strings belong to individual widgets -- don't free them */
-	g_hash_table_destroy(priv->longname_hash);
+	if (priv) {
+		if (priv->tree)
+			glade_widget_tree_unref(priv->tree);
+		/* strings are owned in the cached GladeWidgetTree structure */
+		g_hash_table_destroy(priv->name_hash);
+		/* strings belong to individual widgets -- don't free them */
+		g_hash_table_destroy(priv->longname_hash);
 
-	g_hash_table_foreach(priv->signals, (GHFunc)glade_xml_destroy_signals,
-			     NULL);
-	g_hash_table_destroy(priv->signals);
+		g_hash_table_foreach(priv->signals,
+				     (GHFunc)glade_xml_destroy_signals, NULL);
+		g_hash_table_destroy(priv->signals);
 
-	/* the group name strings are owned by the GladeWidgetTree */
-	g_hash_table_foreach(self->priv->radio_groups, free_radio_groups,NULL);
-	g_hash_table_destroy(priv->radio_groups);
-	
-	g_free (self->priv);
+		/* the group name strings are owned by the GladeWidgetTree */
+		g_hash_table_foreach(self->priv->radio_groups,
+				     free_radio_groups, NULL);
+		g_hash_table_destroy(priv->radio_groups);
+
+		if (priv->tooltips)
+			gtk_object_unref(GTK_OBJECT(priv->tooltips));
+
+		/* there should only be at most one accel group on stack */
+		if (priv->accel_groups)
+			glade_xml_pop_accel(self);
+
+		g_free (self->priv);
+	}
+	self->priv = NULL;
 	if (parent_class->destroy)
 		(* parent_class->destroy)(object);
 }
@@ -1282,8 +1308,6 @@ glade_xml_set_common_params(GladeXML *self, GtkWidget *widget,
 
 	gtk_widget_set_name(widget, info->name);
 	if (info->tooltip) {
-		if (self->priv->tooltips == NULL)
-			self->priv->tooltips = gtk_tooltips_new();
 		gtk_tooltips_set_tip(self->priv->tooltips,
 				     widget,
 				     glade_xml_gettext(self, info->tooltip),
